# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: kubernetes/kubernetes_io.k8s.api.networking.v1.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_apis_dot_meta_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.api.core import v1_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_api_dot_core_dot_v1__pb2
from oak9.tython.models.kubernetes.kubernetes_io.k8s.apimachinery.pkg.util import intstr_pb2 as kubernetes_dot_kubernetes__io_dot_k8s_dot_apimachinery_dot_pkg_dot_util_dot_intstr__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n4kubernetes/kubernetes_io.k8s.api.networking.v1.proto\x12!oak9.tython.k8s.api.networking.v1\x1a\x13shared/shared.proto\x1a@kubernetes/kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1.proto\x1a.kubernetes/kubernetes_io.k8s.api.core.v1.proto\x1a?kubernetes/kubernetes_io.k8s.apimachinery.pkg.util.intstr.proto\"\xaf\x01\n\x0fHTTPIngressPath\x12\x42\n\x07\x62\x61\x63kend\x18\x01 \x01(\x0b\x32\x31.oak9.tython.k8s.api.networking.v1.IngressBackend\x12\x0c\n\x04path\x18\x02 \x01(\t\x12\x11\n\tpath_type\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x92\x01\n\x14HTTPIngressRuleValue\x12\x41\n\x05paths\x18\x01 \x03(\x0b\x32\x32.oak9.tython.k8s.api.networking.v1.HTTPIngressPath\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"`\n\x07IPBlock\x12\x0c\n\x04\x63idr\x18\x01 \x01(\t\x12\x0e\n\x06\x65xcept\x18\x02 \x03(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb2\x02\n\x07Ingress\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12<\n\x04spec\x18\x04 \x01(\x0b\x32..oak9.tython.k8s.api.networking.v1.IngressSpec\x12@\n\x06status\x18\x05 \x01(\x0b\x32\x30.oak9.tython.k8s.api.networking.v1.IngressStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xde\x01\n\x0eIngressBackend\x12H\n\x08resource\x18\x01 \x01(\x0b\x32\x36.oak9.tython.k8s.api.core.v1.TypedLocalObjectReference\x12I\n\x07service\x18\x02 \x01(\x0b\x32\x38.oak9.tython.k8s.api.networking.v1.IngressServiceBackend\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfa\x01\n\x0cIngressClass\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x41\n\x04spec\x18\x04 \x01(\x0b\x32\x33.oak9.tython.k8s.api.networking.v1.IngressClassSpec\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xf9\x01\n\x10IngressClassList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12>\n\x05items\x18\x02 \x03(\x0b\x32/.oak9.tython.k8s.api.networking.v1.IngressClass\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xab\x01\n\x1fIngressClassParametersReference\x12\x11\n\tapi_group\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x11\n\tnamespace\x18\x04 \x01(\t\x12\r\n\x05scope\x18\x05 \x01(\t\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb7\x01\n\x10IngressClassSpec\x12\x12\n\ncontroller\x18\x01 \x01(\t\x12V\n\nparameters\x18\x02 \x01(\x0b\x32\x42.oak9.tython.k8s.api.networking.v1.IngressClassParametersReference\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xef\x01\n\x0bIngressList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x39\n\x05items\x18\x02 \x03(\x0b\x32*.oak9.tython.k8s.api.networking.v1.Ingress\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x01\n\x1aIngressLoadBalancerIngress\x12\x10\n\x08hostname\x18\x01 \x01(\t\x12\n\n\x02ip\x18\x02 \x01(\t\x12\x43\n\x05ports\x18\x03 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.IngressPortStatus\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa4\x01\n\x19IngressLoadBalancerStatus\x12N\n\x07ingress\x18\x01 \x03(\x0b\x32=.oak9.tython.k8s.api.networking.v1.IngressLoadBalancerIngress\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"{\n\x11IngressPortStatus\x12\r\n\x05\x65rror\x18\x01 \x01(\t\x12\x0c\n\x04port\x18\x02 \x01(\x05\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9b\x01\n\x0bIngressRule\x12\x0c\n\x04host\x18\x01 \x01(\t\x12\x45\n\x04http\x18\x02 \x01(\x0b\x32\x37.oak9.tython.k8s.api.networking.v1.HTTPIngressRuleValue\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa3\x01\n\x15IngressServiceBackend\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x43\n\x04port\x18\x02 \x01(\x0b\x32\x35.oak9.tython.k8s.api.networking.v1.ServiceBackendPort\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xa9\x02\n\x0bIngressSpec\x12J\n\x0f\x64\x65\x66\x61ult_backend\x18\x01 \x01(\x0b\x32\x31.oak9.tython.k8s.api.networking.v1.IngressBackend\x12\x1a\n\x12ingress_class_name\x18\x02 \x01(\t\x12=\n\x05rules\x18\x03 \x03(\x0b\x32..oak9.tython.k8s.api.networking.v1.IngressRule\x12:\n\x03tls\x18\x04 \x03(\x0b\x32-.oak9.tython.k8s.api.networking.v1.IngressTLS\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9d\x01\n\rIngressStatus\x12S\n\rload_balancer\x18\x01 \x01(\x0b\x32<.oak9.tython.k8s.api.networking.v1.IngressLoadBalancerStatus\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"i\n\nIngressTLS\x12\r\n\x05hosts\x18\x01 \x03(\t\x12\x13\n\x0bsecret_name\x18\x02 \x01(\t\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xc4\x02\n\rNetworkPolicy\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12\x0c\n\x04kind\x18\x02 \x01(\t\x12K\n\x08metadata\x18\x03 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ObjectMeta\x12\x42\n\x04spec\x18\x04 \x01(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicySpec\x12\x46\n\x06status\x18\x05 \x01(\x0b\x32\x36.oak9.tython.k8s.api.networking.v1.NetworkPolicyStatus\x12\x37\n\rresource_info\x18\x06 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd9\x01\n\x17NetworkPolicyEgressRule\x12\x43\n\x05ports\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicyPort\x12@\n\x02to\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicyPeer\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xdc\x01\n\x18NetworkPolicyIngressRule\x12\x42\n\x04\x66rom\x18\x01 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicyPeer\x12\x43\n\x05ports\x18\x02 \x03(\x0b\x32\x34.oak9.tython.k8s.api.networking.v1.NetworkPolicyPort\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xfb\x01\n\x11NetworkPolicyList\x12\x13\n\x0b\x61pi_version\x18\x01 \x01(\t\x12?\n\x05items\x18\x02 \x03(\x0b\x32\x30.oak9.tython.k8s.api.networking.v1.NetworkPolicy\x12\x0c\n\x04kind\x18\x03 \x01(\t\x12I\n\x08metadata\x18\x04 \x01(\x0b\x32\x37.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.ListMeta\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb8\x02\n\x11NetworkPolicyPeer\x12<\n\x08ip_block\x18\x01 \x01(\x0b\x32*.oak9.tython.k8s.api.networking.v1.IPBlock\x12X\n\x12namespace_selector\x18\x02 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12R\n\x0cpod_selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb9\x01\n\x11NetworkPolicyPort\x12\x10\n\x08\x65nd_port\x18\x01 \x01(\x05\x12G\n\x04port\x18\x02 \x01(\x0b\x32\x39.oak9.tython.k8s.apimachinery.pkg.util.intstr.IntOrString\x12\x10\n\x08protocol\x18\x03 \x01(\t\x12\x37\n\rresource_info\x18\x04 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xd0\x02\n\x11NetworkPolicySpec\x12J\n\x06\x65gress\x18\x01 \x03(\x0b\x32:.oak9.tython.k8s.api.networking.v1.NetworkPolicyEgressRule\x12L\n\x07ingress\x18\x02 \x03(\x0b\x32;.oak9.tython.k8s.api.networking.v1.NetworkPolicyIngressRule\x12R\n\x0cpod_selector\x18\x03 \x01(\x0b\x32<.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.LabelSelector\x12\x14\n\x0cpolicy_types\x18\x04 \x03(\t\x12\x37\n\rresource_info\x18\x05 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\x9c\x01\n\x13NetworkPolicyStatus\x12L\n\nconditions\x18\x01 \x03(\x0b\x32\x38.oak9.tython.k8s.apimachinery.pkg.apis.meta.v1.Condition\x12\x37\n\rresource_info\x18\x02 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"k\n\x12ServiceBackendPort\x12\x0c\n\x04name\x18\x01 \x01(\t\x12\x0e\n\x06number\x18\x02 \x01(\x05\x12\x37\n\rresource_info\x18\x03 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfob\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'kubernetes.kubernetes_io.k8s.api.networking.v1_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _HTTPINGRESSPATH._serialized_start=292
  _HTTPINGRESSPATH._serialized_end=467
  _HTTPINGRESSRULEVALUE._serialized_start=470
  _HTTPINGRESSRULEVALUE._serialized_end=616
  _IPBLOCK._serialized_start=618
  _IPBLOCK._serialized_end=714
  _INGRESS._serialized_start=717
  _INGRESS._serialized_end=1023
  _INGRESSBACKEND._serialized_start=1026
  _INGRESSBACKEND._serialized_end=1248
  _INGRESSCLASS._serialized_start=1251
  _INGRESSCLASS._serialized_end=1501
  _INGRESSCLASSLIST._serialized_start=1504
  _INGRESSCLASSLIST._serialized_end=1753
  _INGRESSCLASSPARAMETERSREFERENCE._serialized_start=1756
  _INGRESSCLASSPARAMETERSREFERENCE._serialized_end=1927
  _INGRESSCLASSSPEC._serialized_start=1930
  _INGRESSCLASSSPEC._serialized_end=2113
  _INGRESSLIST._serialized_start=2116
  _INGRESSLIST._serialized_end=2355
  _INGRESSLOADBALANCERINGRESS._serialized_start=2358
  _INGRESSLOADBALANCERINGRESS._serialized_end=2542
  _INGRESSLOADBALANCERSTATUS._serialized_start=2545
  _INGRESSLOADBALANCERSTATUS._serialized_end=2709
  _INGRESSPORTSTATUS._serialized_start=2711
  _INGRESSPORTSTATUS._serialized_end=2834
  _INGRESSRULE._serialized_start=2837
  _INGRESSRULE._serialized_end=2992
  _INGRESSSERVICEBACKEND._serialized_start=2995
  _INGRESSSERVICEBACKEND._serialized_end=3158
  _INGRESSSPEC._serialized_start=3161
  _INGRESSSPEC._serialized_end=3458
  _INGRESSSTATUS._serialized_start=3461
  _INGRESSSTATUS._serialized_end=3618
  _INGRESSTLS._serialized_start=3620
  _INGRESSTLS._serialized_end=3725
  _NETWORKPOLICY._serialized_start=3728
  _NETWORKPOLICY._serialized_end=4052
  _NETWORKPOLICYEGRESSRULE._serialized_start=4055
  _NETWORKPOLICYEGRESSRULE._serialized_end=4272
  _NETWORKPOLICYINGRESSRULE._serialized_start=4275
  _NETWORKPOLICYINGRESSRULE._serialized_end=4495
  _NETWORKPOLICYLIST._serialized_start=4498
  _NETWORKPOLICYLIST._serialized_end=4749
  _NETWORKPOLICYPEER._serialized_start=4752
  _NETWORKPOLICYPEER._serialized_end=5064
  _NETWORKPOLICYPORT._serialized_start=5067
  _NETWORKPOLICYPORT._serialized_end=5252
  _NETWORKPOLICYSPEC._serialized_start=5255
  _NETWORKPOLICYSPEC._serialized_end=5591
  _NETWORKPOLICYSTATUS._serialized_start=5594
  _NETWORKPOLICYSTATUS._serialized_end=5750
  _SERVICEBACKENDPORT._serialized_start=5752
  _SERVICEBACKENDPORT._serialized_end=5859
# @@protoc_insertion_point(module_scope)



import json
import os
import sys
from io import StringIO
from typing import Protocol, runtime_checkable, Set, Optional, List
from core.services.tython_api_service import TythonApiService
from core.bp_metadata_utils.customer_blueprint_repo import CustomerBlueprintRepo
from core.bp_metadata_utils.python_source_file_utils import get_blueprint_classes
from core.types import Finding, Configuration
import core.utilities as Utilities
from core.bp_metadata_utils.blueprint_meta_data import BlueprintMetaData


@runtime_checkable
class SupportsValidation(Protocol):
    def validate(self) -> Set[Finding]:
        """
        Entry point into component's validation logic
        """


class Runner:

    @staticmethod
    def run(validation_target: SupportsValidation):
        return validation_target.validate()


def main(argv):
    stdout = sys.stdout
    sys.stdout = runner_stdout = StringIO()

    args_path = None
    findings = set()
    blueprint_metadata_list = []
    blueprint_problems = []

    try:

        if len(argv) > 0:
            args_path = argv[0]
        else:
            sys.stderr.write("Configuration path was not provided.")
            sys.exit(1)

        config = None
        try:
            args_file = open(args_path)
            args_obj = json.load(args_file)
            args_file.close()
            Utilities.verify_config_arguments(args_obj)
            config = Configuration(**args_obj)
        except:
            raise Exception("Runner arguments not found or could not be understood.")

        runner = Runner()

        blueprint_repo = CustomerBlueprintRepo(config.blueprint_package_path)
        blueprint_metadata_list = blueprint_repo.blueprints

        environment_id = TythonApiService.get_default_environment(config)
        request_id = TythonApiService.build_app(config, environment_id)
        runner_inputs = TythonApiService.fetch_graph_data(config, environment_id, request_id)

        # get all blueprint classes
        # TODO: filter out import of base Blueprint class
        blueprint_classes = []
        for path in blueprint_repo.blueprint_file_paths:
            blueprint_classes.extend(get_blueprint_classes(path))

        # Run each blueprint
        for blueprint in blueprint_classes:
            customer_blueprint = blueprint[1](graph=runner_inputs)
            # TODO: check usage guidelines to see if findings should be reported
            try:
                findings = runner.run(customer_blueprint)
            except Exception as e:
                blueprint_problems.append(str(e))
            
        if config.mode == "apply" and findings:
            TythonApiService.apply_findings(config, list(findings), environment_id, request_id)

        sys.exit(0)

    except Exception as e:
        sys.stderr.write(str(e))
        sys.stderr.flush()
        sys.exit(1)

    finally:
        Utilities.persist_runner_output(args_path, runner_stdout, blueprint_problems, blueprint_metadata_list, list(findings))
        sys.stdout = stdout


if __package__ == "":
    # Resulting path is the name of the wheel itself
    path = os.path.dirname(__file__)
    sys.path.insert(0, path)

if __name__ == "__main__":
    import sys

    main(sys.argv[1:])



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_RecoveryServices(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    VAULTS_FIELD_NUMBER: builtins.int
    @property
    def vaults(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Vaults]: ...
    def __init__(
        self,
        *,
        vaults: collections.abc.Iterable[global___Vaults] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["vaults", b"vaults"]) -> None: ...

global___Microsoft_RecoveryServices = Microsoft_RecoveryServices

@typing_extensions.final
class VaultsExtendedInformation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ALGORITHM_FIELD_NUMBER: builtins.int
    ENCRYPTION_KEY_FIELD_NUMBER: builtins.int
    ENCRYPTION_KEY_THUMBPRINT_FIELD_NUMBER: builtins.int
    INTEGRITY_KEY_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    name: builtins.str
    algorithm: builtins.str
    encryption_key: builtins.str
    encryption_key_thumbprint: builtins.str
    integrity_key: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        name: builtins.str = ...,
        algorithm: builtins.str = ...,
        encryption_key: builtins.str = ...,
        encryption_key_thumbprint: builtins.str = ...,
        integrity_key: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["algorithm", b"algorithm", "encryption_key", b"encryption_key", "encryption_key_thumbprint", b"encryption_key_thumbprint", "etag", b"etag", "integrity_key", b"integrity_key", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___VaultsExtendedInformation = VaultsExtendedInformation

@typing_extensions.final
class VaultsCertificates(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    AUTH_TYPE_FIELD_NUMBER: builtins.int
    CERTIFICATE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    auth_type: builtins.str
    certificate: builtins.str
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        auth_type: builtins.str = ...,
        certificate: builtins.str = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["auth_type", b"auth_type", "certificate", b"certificate", "name", b"name", "resource_info", b"resource_info"]) -> None: ...

global___VaultsCertificates = VaultsCertificates

@typing_extensions.final
class Vaults(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    ETAG_FIELD_NUMBER: builtins.int
    IDENTITY_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ENCRYPTION_FIELD_NUMBER: builtins.int
    MOVE_DETAILS_FIELD_NUMBER: builtins.int
    UPGRADE_DETAILS_FIELD_NUMBER: builtins.int
    SKU_FIELD_NUMBER: builtins.int
    SYSTEM_DATA_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    VAULTS_CERTIFICATES_FIELD_NUMBER: builtins.int
    VAULTS_EXTENDED_INFORMATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    etag: builtins.str
    @property
    def identity(self) -> global___IdentityData: ...
    location: builtins.str
    name: builtins.str
    @property
    def encryption(self) -> global___VaultPropertiesEncryption: ...
    @property
    def move_details(self) -> global___VaultPropertiesMoveDetails: ...
    @property
    def upgrade_details(self) -> global___UpgradeDetails: ...
    @property
    def sku(self) -> global___Sku: ...
    @property
    def system_data(self) -> global___SystemData: ...
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def vaults_certificates(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsCertificates]: ...
    @property
    def vaults_extended_information(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___VaultsExtendedInformation]: ...
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        etag: builtins.str = ...,
        identity: global___IdentityData | None = ...,
        location: builtins.str = ...,
        name: builtins.str = ...,
        encryption: global___VaultPropertiesEncryption | None = ...,
        move_details: global___VaultPropertiesMoveDetails | None = ...,
        upgrade_details: global___UpgradeDetails | None = ...,
        sku: global___Sku | None = ...,
        system_data: global___SystemData | None = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        vaults_certificates: collections.abc.Iterable[global___VaultsCertificates] | None = ...,
        vaults_extended_information: collections.abc.Iterable[global___VaultsExtendedInformation] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["encryption", b"encryption", "identity", b"identity", "move_details", b"move_details", "resource_info", b"resource_info", "sku", b"sku", "system_data", b"system_data", "upgrade_details", b"upgrade_details"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["encryption", b"encryption", "etag", b"etag", "identity", b"identity", "location", b"location", "move_details", b"move_details", "name", b"name", "resource_info", b"resource_info", "sku", b"sku", "system_data", b"system_data", "tags", b"tags", "upgrade_details", b"upgrade_details", "vaults_certificates", b"vaults_certificates", "vaults_extended_information", b"vaults_extended_information"]) -> None: ...

global___Vaults = Vaults

@typing_extensions.final
class SystemData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATED_AT_FIELD_NUMBER: builtins.int
    CREATED_BY_FIELD_NUMBER: builtins.int
    CREATED_BY_TYPE_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_AT_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_FIELD_NUMBER: builtins.int
    LAST_MODIFIED_BY_TYPE_FIELD_NUMBER: builtins.int
    created_at: builtins.str
    created_by: builtins.str
    created_by_type: builtins.str
    last_modified_at: builtins.str
    last_modified_by: builtins.str
    last_modified_by_type: builtins.str
    def __init__(
        self,
        *,
        created_at: builtins.str = ...,
        created_by: builtins.str = ...,
        created_by_type: builtins.str = ...,
        last_modified_at: builtins.str = ...,
        last_modified_by: builtins.str = ...,
        last_modified_by_type: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["created_at", b"created_at", "created_by", b"created_by", "created_by_type", b"created_by_type", "last_modified_at", b"last_modified_at", "last_modified_by", b"last_modified_by", "last_modified_by_type", b"last_modified_by_type"]) -> None: ...

global___SystemData = SystemData

@typing_extensions.final
class Sku(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CAPACITY_FIELD_NUMBER: builtins.int
    FAMILY_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    SIZE_FIELD_NUMBER: builtins.int
    TIER_FIELD_NUMBER: builtins.int
    capacity: builtins.str
    family: builtins.str
    name: builtins.str
    size: builtins.str
    tier: builtins.str
    def __init__(
        self,
        *,
        capacity: builtins.str = ...,
        family: builtins.str = ...,
        name: builtins.str = ...,
        size: builtins.str = ...,
        tier: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["capacity", b"capacity", "family", b"family", "name", b"name", "size", b"size", "tier", b"tier"]) -> None: ...

global___Sku = Sku

@typing_extensions.final
class UpgradeDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___UpgradeDetails = UpgradeDetails

@typing_extensions.final
class VaultPropertiesMoveDetails(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    NAME_FIELD_NUMBER: builtins.int
    name: builtins.str
    def __init__(
        self,
        *,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["name", b"name"]) -> None: ...

global___VaultPropertiesMoveDetails = VaultPropertiesMoveDetails

@typing_extensions.final
class VaultPropertiesEncryption(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    INFRASTRUCTURE_ENCRYPTION_FIELD_NUMBER: builtins.int
    KEK_IDENTITY_FIELD_NUMBER: builtins.int
    KEY_VAULT_PROPERTIES_FIELD_NUMBER: builtins.int
    infrastructure_encryption: builtins.str
    @property
    def kek_identity(self) -> global___CmkKekIdentity: ...
    @property
    def key_vault_properties(self) -> global___CmkKeyVaultProperties: ...
    def __init__(
        self,
        *,
        infrastructure_encryption: builtins.str = ...,
        kek_identity: global___CmkKekIdentity | None = ...,
        key_vault_properties: global___CmkKeyVaultProperties | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["kek_identity", b"kek_identity", "key_vault_properties", b"key_vault_properties"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["infrastructure_encryption", b"infrastructure_encryption", "kek_identity", b"kek_identity", "key_vault_properties", b"key_vault_properties"]) -> None: ...

global___VaultPropertiesEncryption = VaultPropertiesEncryption

@typing_extensions.final
class CmkKeyVaultProperties(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    KEY_URI_FIELD_NUMBER: builtins.int
    key_uri: builtins.str
    def __init__(
        self,
        *,
        key_uri: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["key_uri", b"key_uri"]) -> None: ...

global___CmkKeyVaultProperties = CmkKeyVaultProperties

@typing_extensions.final
class CmkKekIdentity(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    USER_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    USE_SYSTEM_ASSIGNED_IDENTITY_FIELD_NUMBER: builtins.int
    user_assigned_identity: builtins.str
    use_system_assigned_identity: builtins.bool
    def __init__(
        self,
        *,
        user_assigned_identity: builtins.str = ...,
        use_system_assigned_identity: builtins.bool = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["use_system_assigned_identity", b"use_system_assigned_identity", "user_assigned_identity", b"user_assigned_identity"]) -> None: ...

global___CmkKekIdentity = CmkKekIdentity

@typing_extensions.final
class IdentityData(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class UserAssignedIdentitiesEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    TYPE_FIELD_NUMBER: builtins.int
    USER_ASSIGNED_IDENTITIES_FIELD_NUMBER: builtins.int
    type: builtins.str
    @property
    def user_assigned_identities(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    def __init__(
        self,
        *,
        type: builtins.str = ...,
        user_assigned_identities: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["type", b"type", "user_assigned_identities", b"user_assigned_identities"]) -> None: ...

global___IdentityData = IdentityData



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: gcp/gcp_google_dns_bundle.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2
from oak9.tython.models.gcp import gcp_dns_pb2 as gcp_dot_gcp__dns__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1fgcp/gcp_google_dns_bundle.proto\x12!oak9.tython.gcp.google_dns_bundle\x1a\x13shared/shared.proto\x1a\x11gcp/gcp_dns.proto\"\xb9\x01\n\tGoogleDns\x12=\n\x10\x64ns_managed_zone\x18\x01 \x01(\x0b\x32#.oak9.tython.gcp.dns.DnsManagedZone\x12\x32\n\ndns_policy\x18\x02 \x01(\x0b\x32\x1e.oak9.tython.gcp.dns.DnsPolicy\x12\x39\n\x0e\x64ns_record_set\x18\x03 \x01(\x0b\x32!.oak9.tython.gcp.dns.DnsRecordSetb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'gcp.gcp_google_dns_bundle_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GOOGLEDNS._serialized_start=111
  _GOOGLEDNS._serialized_end=296
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_ecs.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11\x61ws/aws_ecs.proto\x12\x13oak9.tython.aws.ecs\x1a\x13shared/shared.proto\"\xc8\x01\n\x1e\x43\x61pacityProviderManagedScaling\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12!\n\x19minimum_scaling_step_size\x18\x02 \x01(\x05\x12!\n\x19maximum_scaling_step_size\x18\x03 \x01(\x05\x12\x0e\n\x06status\x18\x04 \x01(\t\x12\x17\n\x0ftarget_capacity\x18\x05 \x01(\x05\"\xf9\x01\n(CapacityProviderAutoScalingGroupProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1e\n\x16\x61uto_scaling_group_arn\x18\x02 \x01(\t\x12L\n\x0fmanaged_scaling\x18\x03 \x01(\x0b\x32\x33.oak9.tython.aws.ecs.CapacityProviderManagedScaling\x12&\n\x1emanaged_termination_protection\x18\x04 \x01(\t\"\xa9\x02\n\x10\x43\x61pacityProvider\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x62\n\x1b\x61uto_scaling_group_provider\x18\x02 \x01(\x0b\x32=.oak9.tython.aws.ecs.CapacityProviderAutoScalingGroupProvider\x12\x0c\n\x04name\x18\x03 \x01(\t\x12=\n\x04tags\x18\x04 \x03(\x0b\x32/.oak9.tython.aws.ecs.CapacityProvider.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xd2\x02\n\x03\x45\x43S\x12@\n\x11\x63\x61pacity_provider\x18\x01 \x03(\x0b\x32%.oak9.tython.aws.ecs.CapacityProvider\x12-\n\x07\x63luster\x18\x02 \x01(\x0b\x32\x1c.oak9.tython.aws.ecs.Cluster\x12=\n\x10primary_task_set\x18\x03 \x01(\x0b\x32#.oak9.tython.aws.ecs.PrimaryTaskSet\x12-\n\x07service\x18\x04 \x03(\x0b\x32\x1c.oak9.tython.aws.ecs.Service\x12<\n\x0ftask_definition\x18\x05 \x03(\x0b\x32#.oak9.tython.aws.ecs.TaskDefinition\x12.\n\x08task_set\x18\x06 \x03(\x0b\x32\x1c.oak9.tython.aws.ecs.TaskSet\"n\n\x16\x43lusterClusterSettings\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\x97\x01\n#ClusterCapacityProviderStrategyItem\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11\x63\x61pacity_provider\x18\x02 \x01(\t\x12\x0e\n\x06weight\x18\x03 \x01(\x05\x12\x0c\n\x04\x62\x61se\x18\x04 \x01(\x05\"\x84\x03\n\x07\x43luster\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x34\n\x04tags\x18\x02 \x03(\x0b\x32&.oak9.tython.aws.ecs.Cluster.TagsEntry\x12\x14\n\x0c\x63luster_name\x18\x03 \x01(\t\x12\x45\n\x10\x63luster_settings\x18\x04 \x03(\x0b\x32+.oak9.tython.aws.ecs.ClusterClusterSettings\x12\x1a\n\x12\x63\x61pacity_providers\x18\x05 \x03(\t\x12\x64\n\"default_capacity_provider_strategy\x18\x06 \x03(\x0b\x32\x38.oak9.tython.aws.ecs.ClusterCapacityProviderStrategyItem\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x80\x01\n\x0ePrimaryTaskSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x13\n\x0btask_set_id\x18\x03 \x01(\t\x12\x0f\n\x07service\x18\x04 \x01(\t\"\x97\x01\n#ServiceCapacityProviderStrategyItem\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04\x62\x61se\x18\x02 \x01(\x05\x12\x19\n\x11\x63\x61pacity_provider\x18\x03 \x01(\t\x12\x0e\n\x06weight\x18\x04 \x01(\x05\"\x93\x01\n\x1eServiceDeploymentConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x17\n\x0fmaximum_percent\x18\x02 \x01(\x05\x12\x1f\n\x17minimum_healthy_percent\x18\x03 \x01(\x05\"V\n\x1bServiceDeploymentController\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\"\xb4\x01\n\x13ServiceLoadBalancer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontainer_port\x18\x03 \x01(\x05\x12\x1a\n\x12load_balancer_name\x18\x04 \x01(\t\x12\x18\n\x10target_group_arn\x18\x05 \x01(\t\"\x99\x01\n\x1aServiceAwsVpcConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61ssign_public_ip\x18\x02 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x03 \x03(\t\x12\x0f\n\x07subnets\x18\x04 \x03(\t\"\xa6\x01\n\x1bServiceNetworkConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\x15\x61ws_vpc_configuration\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.ecs.ServiceAwsVpcConfiguration\"i\n\x1aServicePlacementConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nexpression\x18\x02 \x01(\t\"b\n\x18ServicePlacementStrategy\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05\x66ield\x18\x02 \x01(\t\"\xa5\x01\n\x16ServiceServiceRegistry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontainer_port\x18\x03 \x01(\x05\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x14\n\x0cregistry_arn\x18\x05 \x01(\t\"\xce\x08\n\x07Service\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bservice_arn\x18\x02 \x01(\t\x12\\\n\x1a\x63\x61pacity_provider_strategy\x18\x03 \x03(\x0b\x32\x38.oak9.tython.aws.ecs.ServiceCapacityProviderStrategyItem\x12\x0f\n\x07\x63luster\x18\x04 \x01(\t\x12U\n\x18\x64\x65ployment_configuration\x18\x05 \x01(\x0b\x32\x33.oak9.tython.aws.ecs.ServiceDeploymentConfiguration\x12O\n\x15\x64\x65ployment_controller\x18\x06 \x01(\x0b\x32\x30.oak9.tython.aws.ecs.ServiceDeploymentController\x12\x15\n\rdesired_count\x18\x07 \x01(\x05\x12\x1f\n\x17\x65nable_ecs_managed_tags\x18\x08 \x01(\x08\x12)\n!health_check_grace_period_seconds\x18\t \x01(\x05\x12\x13\n\x0blaunch_type\x18\n \x01(\t\x12@\n\x0eload_balancers\x18\x0b \x03(\x0b\x32(.oak9.tython.aws.ecs.ServiceLoadBalancer\x12O\n\x15network_configuration\x18\x0c \x01(\x0b\x32\x30.oak9.tython.aws.ecs.ServiceNetworkConfiguration\x12N\n\x15placement_constraints\x18\r \x03(\x0b\x32/.oak9.tython.aws.ecs.ServicePlacementConstraint\x12K\n\x14placement_strategies\x18\x0e \x03(\x0b\x32-.oak9.tython.aws.ecs.ServicePlacementStrategy\x12\x18\n\x10platform_version\x18\x0f \x01(\t\x12\x16\n\x0epropagate_tags\x18\x10 \x01(\t\x12\x0c\n\x04role\x18\x11 \x01(\t\x12\x1b\n\x13scheduling_strategy\x18\x12 \x01(\t\x12\x14\n\x0cservice_name\x18\x13 \x01(\t\x12G\n\x12service_registries\x18\x14 \x03(\x0b\x32+.oak9.tython.aws.ecs.ServiceServiceRegistry\x12\x34\n\x04tags\x18\x15 \x03(\x0b\x32&.oak9.tython.aws.ecs.Service.TagsEntry\x12\x17\n\x0ftask_definition\x18\x16 \x01(\t\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"r\n\x1aTaskDefinitionKeyValuePair\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"g\n\x1dTaskDefinitionEnvironmentFile\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"x\n\x17TaskDefinitionHostEntry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08hostname\x18\x02 \x01(\t\x12\x12\n\nip_address\x18\x03 \x01(\t\"\xe6\x01\n#TaskDefinitionFirelensConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12V\n\x07options\x18\x02 \x03(\x0b\x32\x45.oak9.tython.aws.ecs.TaskDefinitionFirelensConfiguration.OptionsEntry\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xaf\x01\n\x19TaskDefinitionHealthCheck\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\x10\n\x08interval\x18\x03 \x01(\x05\x12\x0f\n\x07timeout\x18\x04 \x01(\x05\x12\x0f\n\x07retries\x18\x05 \x01(\x05\x12\x14\n\x0cstart_period\x18\x06 \x01(\x05\"v\n TaskDefinitionKernelCapabilities\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03\x61\x64\x64\x18\x02 \x03(\t\x12\x0c\n\x04\x64rop\x18\x03 \x03(\t\"\x8f\x01\n\x14TaskDefinitionDevice\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_path\x18\x02 \x01(\t\x12\x11\n\thost_path\x18\x03 \x01(\t\x12\x13\n\x0bpermissions\x18\x04 \x03(\t\"\x8b\x01\n\x13TaskDefinitionTmpfs\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_path\x18\x02 \x01(\t\x12\x15\n\rmount_options\x18\x03 \x03(\t\x12\x0c\n\x04size\x18\x04 \x01(\x05\"\xfa\x02\n\x1dTaskDefinitionLinuxParameters\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12K\n\x0c\x63\x61pabilities\x18\x02 \x01(\x0b\x32\x35.oak9.tython.aws.ecs.TaskDefinitionKernelCapabilities\x12:\n\x07\x64\x65vices\x18\x03 \x03(\x0b\x32).oak9.tython.aws.ecs.TaskDefinitionDevice\x12\x1c\n\x14init_process_enabled\x18\x04 \x01(\x08\x12\x10\n\x08max_swap\x18\x05 \x01(\x05\x12\x1a\n\x12shared_memory_size\x18\x06 \x01(\x05\x12\x12\n\nswappiness\x18\x07 \x01(\x05\x12\x37\n\x05tmpfs\x18\x08 \x03(\x0b\x32(.oak9.tython.aws.ecs.TaskDefinitionTmpfs\"q\n\x14TaskDefinitionSecret\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x12\n\nvalue_from\x18\x03 \x01(\t\"\xb3\x02\n\x1eTaskDefinitionLogConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nlog_driver\x18\x02 \x01(\t\x12Q\n\x07options\x18\x03 \x03(\x0b\x32@.oak9.tython.aws.ecs.TaskDefinitionLogConfiguration.OptionsEntry\x12\x41\n\x0esecret_options\x18\x04 \x03(\x0b\x32).oak9.tython.aws.ecs.TaskDefinitionSecret\x1a.\n\x0cOptionsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x95\x01\n\x18TaskDefinitionMountPoint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_path\x18\x02 \x01(\t\x12\x11\n\tread_only\x18\x03 \x01(\x08\x12\x15\n\rsource_volume\x18\x04 \x01(\t\"\x91\x01\n\x19TaskDefinitionPortMapping\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_port\x18\x02 \x01(\x05\x12\x11\n\thost_port\x18\x03 \x01(\x05\x12\x10\n\x08protocol\x18\x04 \x01(\t\"}\n#TaskDefinitionRepositoryCredentials\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1d\n\x15\x63redentials_parameter\x18\x02 \x01(\t\"k\n!TaskDefinitionResourceRequirement\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\r\n\x05value\x18\x02 \x01(\t\"\x85\x01\n\x14TaskDefinitionUlimit\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nhard_limit\x18\x02 \x01(\x05\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x12\n\nsoft_limit\x18\x04 \x01(\x05\"\x80\x01\n\x18TaskDefinitionVolumeFrom\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tread_only\x18\x02 \x01(\x08\x12\x18\n\x10source_container\x18\x03 \x01(\t\"x\n\x1bTaskDefinitionSystemControl\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x11\n\tnamespace\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xa5\x0e\n!TaskDefinitionContainerDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63ommand\x18\x02 \x03(\t\x12\x0b\n\x03\x63pu\x18\x03 \x01(\x05\x12\x1a\n\x12\x64isable_networking\x18\x04 \x01(\x08\x12\x1a\n\x12\x64ns_search_domains\x18\x05 \x03(\t\x12\x13\n\x0b\x64ns_servers\x18\x06 \x03(\t\x12_\n\rdocker_labels\x18\x07 \x03(\x0b\x32H.oak9.tython.aws.ecs.TaskDefinitionContainerDefinition.DockerLabelsEntry\x12\x1f\n\x17\x64ocker_security_options\x18\x08 \x03(\t\x12\x13\n\x0b\x65ntry_point\x18\t \x03(\t\x12\x44\n\x0b\x65nvironment\x18\n \x03(\x0b\x32/.oak9.tython.aws.ecs.TaskDefinitionKeyValuePair\x12M\n\x11\x65nvironment_files\x18\x0b \x03(\x0b\x32\x32.oak9.tython.aws.ecs.TaskDefinitionEnvironmentFile\x12\x11\n\tessential\x18\x0c \x01(\x08\x12\x41\n\x0b\x65xtra_hosts\x18\r \x03(\x0b\x32,.oak9.tython.aws.ecs.TaskDefinitionHostEntry\x12X\n\x16\x66irelens_configuration\x18\x0e \x01(\x0b\x32\x38.oak9.tython.aws.ecs.TaskDefinitionFirelensConfiguration\x12\x44\n\x0chealth_check\x18\x0f \x01(\x0b\x32..oak9.tython.aws.ecs.TaskDefinitionHealthCheck\x12\x10\n\x08hostname\x18\x10 \x01(\t\x12\r\n\x05image\x18\x11 \x01(\t\x12\r\n\x05links\x18\x12 \x03(\t\x12L\n\x10linux_parameters\x18\x13 \x01(\x0b\x32\x32.oak9.tython.aws.ecs.TaskDefinitionLinuxParameters\x12N\n\x11log_configuration\x18\x14 \x01(\x0b\x32\x33.oak9.tython.aws.ecs.TaskDefinitionLogConfiguration\x12\x0e\n\x06memory\x18\x15 \x01(\x05\x12\x1a\n\x12memory_reservation\x18\x16 \x01(\x05\x12\x43\n\x0cmount_points\x18\x17 \x03(\x0b\x32-.oak9.tython.aws.ecs.TaskDefinitionMountPoint\x12\x0c\n\x04name\x18\x18 \x01(\t\x12\x45\n\rport_mappings\x18\x19 \x03(\x0b\x32..oak9.tython.aws.ecs.TaskDefinitionPortMapping\x12\x12\n\nprivileged\x18\x1a \x01(\x08\x12 \n\x18readonly_root_filesystem\x18\x1b \x01(\x08\x12X\n\x16repository_credentials\x18\x1c \x01(\x0b\x32\x38.oak9.tython.aws.ecs.TaskDefinitionRepositoryCredentials\x12U\n\x15resource_requirements\x18\x1d \x03(\x0b\x32\x36.oak9.tython.aws.ecs.TaskDefinitionResourceRequirement\x12:\n\x07secrets\x18\x1e \x03(\x0b\x32).oak9.tython.aws.ecs.TaskDefinitionSecret\x12\x15\n\rstart_timeout\x18\x1f \x01(\x05\x12\x14\n\x0cstop_timeout\x18  \x01(\x05\x12:\n\x07ulimits\x18! \x03(\x0b\x32).oak9.tython.aws.ecs.TaskDefinitionUlimit\x12\x0c\n\x04user\x18\" \x01(\t\x12\x43\n\x0cvolumes_from\x18# \x03(\x0b\x32-.oak9.tython.aws.ecs.TaskDefinitionVolumeFrom\x12\x19\n\x11working_directory\x18$ \x01(\t\x12\x13\n\x0binteractive\x18% \x01(\x08\x12\x17\n\x0fpseudo_terminal\x18& \x01(\x08\x12I\n\x0fsystem_controls\x18\' \x03(\x0b\x32\x30.oak9.tython.aws.ecs.TaskDefinitionSystemControl\x1a\x33\n\x11\x44ockerLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\x87\x01\n\"TaskDefinitionInferenceAccelerator\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0b\x64\x65vice_name\x18\x02 \x01(\t\x12\x13\n\x0b\x64\x65vice_type\x18\x03 \x01(\t\"~\n/TaskDefinitionTaskDefinitionPlacementConstraint\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nexpression\x18\x02 \x01(\t\"\xcc\x01\n TaskDefinitionProxyConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_name\x18\x02 \x01(\t\x12W\n\x1eproxy_configuration_properties\x18\x03 \x03(\x0b\x32/.oak9.tython.aws.ecs.TaskDefinitionKeyValuePair\"\xb7\x03\n\'TaskDefinitionDockerVolumeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rautoprovision\x18\x02 \x01(\x08\x12\x0e\n\x06\x64river\x18\x03 \x01(\t\x12\x61\n\x0b\x64river_opts\x18\x04 \x03(\x0b\x32L.oak9.tython.aws.ecs.TaskDefinitionDockerVolumeConfiguration.DriverOptsEntry\x12X\n\x06labels\x18\x05 \x03(\x0b\x32H.oak9.tython.aws.ecs.TaskDefinitionDockerVolumeConfiguration.LabelsEntry\x12\r\n\x05scope\x18\x06 \x01(\t\x1a\x31\n\x0f\x44riverOptsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\x1a-\n\x0bLabelsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa1\x02\n$TaskDefinitionEFSVolumeConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x15\n\rfilesystem_id\x18\x02 \x01(\t\x12\x16\n\x0eroot_directory\x18\x03 \x01(\t\x12\x1a\n\x12transit_encryption\x18\x04 \x01(\t\x12\x1f\n\x17transit_encryption_port\x18\x05 \x01(\x05\x12T\n\x14\x61uthorization_config\x18\x06 \x01(\x0b\x32\x36.oak9.tython.aws.ecs.TaskDefinitionAuthorizationConfig\"r\n\"TaskDefinitionHostVolumeProperties\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x13\n\x0bsource_path\x18\x02 \x01(\t\"\xe4\x02\n\x14TaskDefinitionVolume\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x61\n\x1b\x64ocker_volume_configuration\x18\x02 \x01(\x0b\x32<.oak9.tython.aws.ecs.TaskDefinitionDockerVolumeConfiguration\x12[\n\x18\x65\x66s_volume_configuration\x18\x03 \x01(\x0b\x32\x39.oak9.tython.aws.ecs.TaskDefinitionEFSVolumeConfiguration\x12\x45\n\x04host\x18\x04 \x01(\x0b\x32\x37.oak9.tython.aws.ecs.TaskDefinitionHostVolumeProperties\x12\x0c\n\x04name\x18\x05 \x01(\t\"\x94\x06\n\x0eTaskDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0e\n\x06\x66\x61mily\x18\x02 \x01(\t\x12U\n\x15\x63ontainer_definitions\x18\x03 \x03(\x0b\x32\x36.oak9.tython.aws.ecs.TaskDefinitionContainerDefinition\x12\x0b\n\x03\x63pu\x18\x04 \x01(\t\x12\x1a\n\x12\x65xecution_role_arn\x18\x05 \x01(\t\x12W\n\x16inference_accelerators\x18\x06 \x03(\x0b\x32\x37.oak9.tython.aws.ecs.TaskDefinitionInferenceAccelerator\x12\x0e\n\x06memory\x18\x07 \x01(\t\x12\x14\n\x0cnetwork_mode\x18\x08 \x01(\t\x12\x63\n\x15placement_constraints\x18\t \x03(\x0b\x32\x44.oak9.tython.aws.ecs.TaskDefinitionTaskDefinitionPlacementConstraint\x12R\n\x13proxy_configuration\x18\n \x01(\x0b\x32\x35.oak9.tython.aws.ecs.TaskDefinitionProxyConfiguration\x12 \n\x18requires_compatibilities\x18\x0b \x03(\t\x12\x15\n\rtask_role_arn\x18\x0c \x01(\t\x12:\n\x07volumes\x18\r \x03(\x0b\x32).oak9.tython.aws.ecs.TaskDefinitionVolume\x12\x10\n\x08pid_mode\x18\x0e \x01(\t\x12\x10\n\x08ipc_mode\x18\x0f \x01(\t\x12;\n\x04tags\x18\x10 \x03(\x0b\x32-.oak9.tython.aws.ecs.TaskDefinition.TagsEntry\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xb4\x01\n\x13TaskSetLoadBalancer\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontainer_port\x18\x03 \x01(\x05\x12\x1a\n\x12load_balancer_name\x18\x04 \x01(\t\x12\x18\n\x10target_group_arn\x18\x05 \x01(\t\"\x99\x01\n\x1aTaskSetAwsVpcConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10\x61ssign_public_ip\x18\x02 \x01(\t\x12\x17\n\x0fsecurity_groups\x18\x03 \x03(\t\x12\x0f\n\x07subnets\x18\x04 \x03(\t\"\xa6\x01\n\x1bTaskSetNetworkConfiguration\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12N\n\x15\x61ws_vpc_configuration\x18\x02 \x01(\x0b\x32/.oak9.tython.aws.ecs.TaskSetAwsVpcConfiguration\"d\n\x0cTaskSetScale\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0c\n\x04unit\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\x01\"\xa5\x01\n\x16TaskSetServiceRegistry\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_name\x18\x02 \x01(\t\x12\x16\n\x0e\x63ontainer_port\x18\x03 \x01(\x05\x12\x0c\n\x04port\x18\x04 \x01(\x05\x12\x14\n\x0cregistry_arn\x18\x05 \x01(\t\"\xcf\x03\n\x07TaskSet\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0f\n\x07\x63luster\x18\x02 \x01(\t\x12\x13\n\x0b\x65xternal_id\x18\x03 \x01(\t\x12\x13\n\x0blaunch_type\x18\x04 \x01(\t\x12@\n\x0eload_balancers\x18\x05 \x03(\x0b\x32(.oak9.tython.aws.ecs.TaskSetLoadBalancer\x12O\n\x15network_configuration\x18\x06 \x01(\x0b\x32\x30.oak9.tython.aws.ecs.TaskSetNetworkConfiguration\x12\x18\n\x10platform_version\x18\x07 \x01(\t\x12\x30\n\x05scale\x18\x08 \x01(\x0b\x32!.oak9.tython.aws.ecs.TaskSetScale\x12\x0f\n\x07service\x18\t \x01(\t\x12G\n\x12service_registries\x18\n \x03(\x0b\x32+.oak9.tython.aws.ecs.TaskSetServiceRegistry\x12\x17\n\x0ftask_definition\x18\x0b \x01(\t\"\x82\x01\n!TaskDefinitionAuthorizationConfig\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03iam\x18\x02 \x01(\t\x12\x17\n\x0f\x61\x63\x63\x65ss_point_id\x18\x03 \x01(\t\"\x87\x01\n!TaskDefinitionContainerDependency\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x63ontainer_name\x18\x02 \x01(\t\x12\x11\n\tcondition\x18\x03 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_ecs_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CAPACITYPROVIDER_TAGSENTRY._options = None
  _CAPACITYPROVIDER_TAGSENTRY._serialized_options = b'8\001'
  _CLUSTER_TAGSENTRY._options = None
  _CLUSTER_TAGSENTRY._serialized_options = b'8\001'
  _SERVICE_TAGSENTRY._options = None
  _SERVICE_TAGSENTRY._serialized_options = b'8\001'
  _TASKDEFINITIONFIRELENSCONFIGURATION_OPTIONSENTRY._options = None
  _TASKDEFINITIONFIRELENSCONFIGURATION_OPTIONSENTRY._serialized_options = b'8\001'
  _TASKDEFINITIONLOGCONFIGURATION_OPTIONSENTRY._options = None
  _TASKDEFINITIONLOGCONFIGURATION_OPTIONSENTRY._serialized_options = b'8\001'
  _TASKDEFINITIONCONTAINERDEFINITION_DOCKERLABELSENTRY._options = None
  _TASKDEFINITIONCONTAINERDEFINITION_DOCKERLABELSENTRY._serialized_options = b'8\001'
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION_DRIVEROPTSENTRY._options = None
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION_DRIVEROPTSENTRY._serialized_options = b'8\001'
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION_LABELSENTRY._options = None
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION_LABELSENTRY._serialized_options = b'8\001'
  _TASKDEFINITION_TAGSENTRY._options = None
  _TASKDEFINITION_TAGSENTRY._serialized_options = b'8\001'
  _CAPACITYPROVIDERMANAGEDSCALING._serialized_start=64
  _CAPACITYPROVIDERMANAGEDSCALING._serialized_end=264
  _CAPACITYPROVIDERAUTOSCALINGGROUPPROVIDER._serialized_start=267
  _CAPACITYPROVIDERAUTOSCALINGGROUPPROVIDER._serialized_end=516
  _CAPACITYPROVIDER._serialized_start=519
  _CAPACITYPROVIDER._serialized_end=816
  _CAPACITYPROVIDER_TAGSENTRY._serialized_start=773
  _CAPACITYPROVIDER_TAGSENTRY._serialized_end=816
  _ECS._serialized_start=819
  _ECS._serialized_end=1157
  _CLUSTERCLUSTERSETTINGS._serialized_start=1159
  _CLUSTERCLUSTERSETTINGS._serialized_end=1269
  _CLUSTERCAPACITYPROVIDERSTRATEGYITEM._serialized_start=1272
  _CLUSTERCAPACITYPROVIDERSTRATEGYITEM._serialized_end=1423
  _CLUSTER._serialized_start=1426
  _CLUSTER._serialized_end=1814
  _CLUSTER_TAGSENTRY._serialized_start=773
  _CLUSTER_TAGSENTRY._serialized_end=816
  _PRIMARYTASKSET._serialized_start=1817
  _PRIMARYTASKSET._serialized_end=1945
  _SERVICECAPACITYPROVIDERSTRATEGYITEM._serialized_start=1948
  _SERVICECAPACITYPROVIDERSTRATEGYITEM._serialized_end=2099
  _SERVICEDEPLOYMENTCONFIGURATION._serialized_start=2102
  _SERVICEDEPLOYMENTCONFIGURATION._serialized_end=2249
  _SERVICEDEPLOYMENTCONTROLLER._serialized_start=2251
  _SERVICEDEPLOYMENTCONTROLLER._serialized_end=2337
  _SERVICELOADBALANCER._serialized_start=2340
  _SERVICELOADBALANCER._serialized_end=2520
  _SERVICEAWSVPCCONFIGURATION._serialized_start=2523
  _SERVICEAWSVPCCONFIGURATION._serialized_end=2676
  _SERVICENETWORKCONFIGURATION._serialized_start=2679
  _SERVICENETWORKCONFIGURATION._serialized_end=2845
  _SERVICEPLACEMENTCONSTRAINT._serialized_start=2847
  _SERVICEPLACEMENTCONSTRAINT._serialized_end=2952
  _SERVICEPLACEMENTSTRATEGY._serialized_start=2954
  _SERVICEPLACEMENTSTRATEGY._serialized_end=3052
  _SERVICESERVICEREGISTRY._serialized_start=3055
  _SERVICESERVICEREGISTRY._serialized_end=3220
  _SERVICE._serialized_start=3223
  _SERVICE._serialized_end=4325
  _SERVICE_TAGSENTRY._serialized_start=773
  _SERVICE_TAGSENTRY._serialized_end=816
  _TASKDEFINITIONKEYVALUEPAIR._serialized_start=4327
  _TASKDEFINITIONKEYVALUEPAIR._serialized_end=4441
  _TASKDEFINITIONENVIRONMENTFILE._serialized_start=4443
  _TASKDEFINITIONENVIRONMENTFILE._serialized_end=4546
  _TASKDEFINITIONHOSTENTRY._serialized_start=4548
  _TASKDEFINITIONHOSTENTRY._serialized_end=4668
  _TASKDEFINITIONFIRELENSCONFIGURATION._serialized_start=4671
  _TASKDEFINITIONFIRELENSCONFIGURATION._serialized_end=4901
  _TASKDEFINITIONFIRELENSCONFIGURATION_OPTIONSENTRY._serialized_start=4855
  _TASKDEFINITIONFIRELENSCONFIGURATION_OPTIONSENTRY._serialized_end=4901
  _TASKDEFINITIONHEALTHCHECK._serialized_start=4904
  _TASKDEFINITIONHEALTHCHECK._serialized_end=5079
  _TASKDEFINITIONKERNELCAPABILITIES._serialized_start=5081
  _TASKDEFINITIONKERNELCAPABILITIES._serialized_end=5199
  _TASKDEFINITIONDEVICE._serialized_start=5202
  _TASKDEFINITIONDEVICE._serialized_end=5345
  _TASKDEFINITIONTMPFS._serialized_start=5348
  _TASKDEFINITIONTMPFS._serialized_end=5487
  _TASKDEFINITIONLINUXPARAMETERS._serialized_start=5490
  _TASKDEFINITIONLINUXPARAMETERS._serialized_end=5868
  _TASKDEFINITIONSECRET._serialized_start=5870
  _TASKDEFINITIONSECRET._serialized_end=5983
  _TASKDEFINITIONLOGCONFIGURATION._serialized_start=5986
  _TASKDEFINITIONLOGCONFIGURATION._serialized_end=6293
  _TASKDEFINITIONLOGCONFIGURATION_OPTIONSENTRY._serialized_start=4855
  _TASKDEFINITIONLOGCONFIGURATION_OPTIONSENTRY._serialized_end=4901
  _TASKDEFINITIONMOUNTPOINT._serialized_start=6296
  _TASKDEFINITIONMOUNTPOINT._serialized_end=6445
  _TASKDEFINITIONPORTMAPPING._serialized_start=6448
  _TASKDEFINITIONPORTMAPPING._serialized_end=6593
  _TASKDEFINITIONREPOSITORYCREDENTIALS._serialized_start=6595
  _TASKDEFINITIONREPOSITORYCREDENTIALS._serialized_end=6720
  _TASKDEFINITIONRESOURCEREQUIREMENT._serialized_start=6722
  _TASKDEFINITIONRESOURCEREQUIREMENT._serialized_end=6829
  _TASKDEFINITIONULIMIT._serialized_start=6832
  _TASKDEFINITIONULIMIT._serialized_end=6965
  _TASKDEFINITIONVOLUMEFROM._serialized_start=6968
  _TASKDEFINITIONVOLUMEFROM._serialized_end=7096
  _TASKDEFINITIONSYSTEMCONTROL._serialized_start=7098
  _TASKDEFINITIONSYSTEMCONTROL._serialized_end=7218
  _TASKDEFINITIONCONTAINERDEFINITION._serialized_start=7221
  _TASKDEFINITIONCONTAINERDEFINITION._serialized_end=9050
  _TASKDEFINITIONCONTAINERDEFINITION_DOCKERLABELSENTRY._serialized_start=8999
  _TASKDEFINITIONCONTAINERDEFINITION_DOCKERLABELSENTRY._serialized_end=9050
  _TASKDEFINITIONINFERENCEACCELERATOR._serialized_start=9053
  _TASKDEFINITIONINFERENCEACCELERATOR._serialized_end=9188
  _TASKDEFINITIONTASKDEFINITIONPLACEMENTCONSTRAINT._serialized_start=9190
  _TASKDEFINITIONTASKDEFINITIONPLACEMENTCONSTRAINT._serialized_end=9316
  _TASKDEFINITIONPROXYCONFIGURATION._serialized_start=9319
  _TASKDEFINITIONPROXYCONFIGURATION._serialized_end=9523
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION._serialized_start=9526
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION._serialized_end=9965
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION_DRIVEROPTSENTRY._serialized_start=9869
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION_DRIVEROPTSENTRY._serialized_end=9918
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION_LABELSENTRY._serialized_start=9920
  _TASKDEFINITIONDOCKERVOLUMECONFIGURATION_LABELSENTRY._serialized_end=9965
  _TASKDEFINITIONEFSVOLUMECONFIGURATION._serialized_start=9968
  _TASKDEFINITIONEFSVOLUMECONFIGURATION._serialized_end=10257
  _TASKDEFINITIONHOSTVOLUMEPROPERTIES._serialized_start=10259
  _TASKDEFINITIONHOSTVOLUMEPROPERTIES._serialized_end=10373
  _TASKDEFINITIONVOLUME._serialized_start=10376
  _TASKDEFINITIONVOLUME._serialized_end=10732
  _TASKDEFINITION._serialized_start=10735
  _TASKDEFINITION._serialized_end=11523
  _TASKDEFINITION_TAGSENTRY._serialized_start=773
  _TASKDEFINITION_TAGSENTRY._serialized_end=816
  _TASKSETLOADBALANCER._serialized_start=11526
  _TASKSETLOADBALANCER._serialized_end=11706
  _TASKSETAWSVPCCONFIGURATION._serialized_start=11709
  _TASKSETAWSVPCCONFIGURATION._serialized_end=11862
  _TASKSETNETWORKCONFIGURATION._serialized_start=11865
  _TASKSETNETWORKCONFIGURATION._serialized_end=12031
  _TASKSETSCALE._serialized_start=12033
  _TASKSETSCALE._serialized_end=12133
  _TASKSETSERVICEREGISTRY._serialized_start=12136
  _TASKSETSERVICEREGISTRY._serialized_end=12301
  _TASKSET._serialized_start=12304
  _TASKSET._serialized_end=12767
  _TASKDEFINITIONAUTHORIZATIONCONFIG._serialized_start=12770
  _TASKDEFINITIONAUTHORIZATIONCONFIG._serialized_end=12900
  _TASKDEFINITIONCONTAINERDEPENDENCY._serialized_start=12903
  _TASKDEFINITIONCONTAINERDEPENDENCY._serialized_end=13038
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_dynamodb_table.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1c\x61ws/aws_dynamodb_table.proto\x12\x1eoak9.tython.aws.dynamodb_table\x1a\x13shared/shared.proto\"\x83\x01\n\x18TableAttributeDefinition\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x16\n\x0e\x61ttribute_type\x18\x03 \x01(\t\"s\n\x0eTableKeySchema\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x10\n\x08key_type\x18\x03 \x01(\t\"\x7f\n\x0fTableProjection\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1a\n\x12non_key_attributes\x18\x02 \x03(\t\x12\x17\n\x0fprojection_type\x18\x03 \x01(\t\"\x90\x01\n\x1aTableProvisionedThroughput\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x1b\n\x13read_capacity_units\x18\x02 \x01(\x05\x12\x1c\n\x14write_capacity_units\x18\x03 \x01(\x05\"\xcd\x02\n\x19TableGlobalSecondaryIndex\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12\x42\n\nkey_schema\x18\x03 \x03(\x0b\x32..oak9.tython.aws.dynamodb_table.TableKeySchema\x12\x43\n\nprojection\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.dynamodb_table.TableProjection\x12Z\n\x16provisioned_throughput\x18\x05 \x01(\x0b\x32:.oak9.tython.aws.dynamodb_table.TableProvisionedThroughput\"\xf0\x01\n\x18TableLocalSecondaryIndex\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x12\n\nindex_name\x18\x02 \x01(\t\x12\x42\n\nkey_schema\x18\x03 \x03(\x0b\x32..oak9.tython.aws.dynamodb_table.TableKeySchema\x12\x43\n\nprojection\x18\x04 \x01(\x0b\x32/.oak9.tython.aws.dynamodb_table.TableProjection\"\x88\x01\n%TablePointInTimeRecoverySpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12&\n\x1epoint_in_time_recovery_enabled\x18\x02 \x01(\x08\"\x92\x01\n\x15TableSSESpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x19\n\x11kms_master_key_id\x18\x02 \x01(\t\x12\x13\n\x0bsse_enabled\x18\x03 \x01(\x08\x12\x10\n\x08sse_type\x18\x04 \x01(\t\"m\n\x18TableStreamSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x18\n\x10stream_view_type\x18\x02 \x01(\t\"\x80\x01\n\x1cTableTimeToLiveSpecification\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x16\n\x0e\x61ttribute_name\x18\x02 \x01(\t\x12\x0f\n\x07\x65nabled\x18\x03 \x01(\x08\"\x88\x08\n\x05Table\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12W\n\x15\x61ttribute_definitions\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.dynamodb_table.TableAttributeDefinition\x12\x14\n\x0c\x62illing_mode\x18\x03 \x01(\t\x12[\n\x18global_secondary_indexes\x18\x04 \x03(\x0b\x32\x39.oak9.tython.aws.dynamodb_table.TableGlobalSecondaryIndex\x12\x42\n\nkey_schema\x18\x05 \x03(\x0b\x32..oak9.tython.aws.dynamodb_table.TableKeySchema\x12Y\n\x17local_secondary_indexes\x18\x06 \x03(\x0b\x32\x38.oak9.tython.aws.dynamodb_table.TableLocalSecondaryIndex\x12s\n$point_in_time_recovery_specification\x18\x07 \x01(\x0b\x32\x45.oak9.tython.aws.dynamodb_table.TablePointInTimeRecoverySpecification\x12Z\n\x16provisioned_throughput\x18\x08 \x01(\x0b\x32:.oak9.tython.aws.dynamodb_table.TableProvisionedThroughput\x12P\n\x11sse_specification\x18\t \x01(\x0b\x32\x35.oak9.tython.aws.dynamodb_table.TableSSESpecification\x12V\n\x14stream_specification\x18\n \x01(\x0b\x32\x38.oak9.tython.aws.dynamodb_table.TableStreamSpecification\x12\x12\n\ntable_name\x18\x0b \x01(\t\x12=\n\x04tags\x18\x0c \x03(\x0b\x32/.oak9.tython.aws.dynamodb_table.Table.TagsEntry\x12`\n\x1atime_to_live_specification\x18\r \x01(\x0b\x32<.oak9.tython.aws.dynamodb_table.TableTimeToLiveSpecification\x1a+\n\tTagsEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"F\n\x0e\x44ynamoDB_Table\x12\x34\n\x05table\x18\x01 \x01(\x0b\x32%.oak9.tython.aws.dynamodb_table.Tableb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_dynamodb_table_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _TABLE_TAGSENTRY._options = None
  _TABLE_TAGSENTRY._serialized_options = b'8\001'
  _TABLEATTRIBUTEDEFINITION._serialized_start=86
  _TABLEATTRIBUTEDEFINITION._serialized_end=217
  _TABLEKEYSCHEMA._serialized_start=219
  _TABLEKEYSCHEMA._serialized_end=334
  _TABLEPROJECTION._serialized_start=336
  _TABLEPROJECTION._serialized_end=463
  _TABLEPROVISIONEDTHROUGHPUT._serialized_start=466
  _TABLEPROVISIONEDTHROUGHPUT._serialized_end=610
  _TABLEGLOBALSECONDARYINDEX._serialized_start=613
  _TABLEGLOBALSECONDARYINDEX._serialized_end=946
  _TABLELOCALSECONDARYINDEX._serialized_start=949
  _TABLELOCALSECONDARYINDEX._serialized_end=1189
  _TABLEPOINTINTIMERECOVERYSPECIFICATION._serialized_start=1192
  _TABLEPOINTINTIMERECOVERYSPECIFICATION._serialized_end=1328
  _TABLESSESPECIFICATION._serialized_start=1331
  _TABLESSESPECIFICATION._serialized_end=1477
  _TABLESTREAMSPECIFICATION._serialized_start=1479
  _TABLESTREAMSPECIFICATION._serialized_end=1588
  _TABLETIMETOLIVESPECIFICATION._serialized_start=1591
  _TABLETIMETOLIVESPECIFICATION._serialized_end=1719
  _TABLE._serialized_start=1722
  _TABLE._serialized_end=2754
  _TABLE_TAGSENTRY._serialized_start=2711
  _TABLE_TAGSENTRY._serialized_end=2754
  _DYNAMODB_TABLE._serialized_start=2756
  _DYNAMODB_TABLE._serialized_end=2826
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    PACKAGE_NAME_FIELD_NUMBER: builtins.int
    SHA1_FINGERPRINT_FIELD_NUMBER: builtins.int
    package_name: builtins.str
    sha1_fingerprint: builtins.str
    def __init__(
        self,
        *,
        package_name: builtins.str = ...,
        sha1_fingerprint: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["package_name", b"package_name", "sha1_fingerprint", b"sha1_fingerprint"]) -> None: ...

global___ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications = ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications

@typing_extensions.final
class ApikeysKeyXRestrictionsXAndroidKeyRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_APPLICATIONS_FIELD_NUMBER: builtins.int
    @property
    def allowed_applications(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications]: ...
    def __init__(
        self,
        *,
        allowed_applications: collections.abc.Iterable[global___ApikeysKeyXRestrictionsXAndroidKeyRestrictionsXAllowedApplications] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_applications", b"allowed_applications"]) -> None: ...

global___ApikeysKeyXRestrictionsXAndroidKeyRestrictions = ApikeysKeyXRestrictionsXAndroidKeyRestrictions

@typing_extensions.final
class ApikeysKeyXRestrictionsXApiTargets(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METHODS_FIELD_NUMBER: builtins.int
    SERVICE_FIELD_NUMBER: builtins.int
    @property
    def methods(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    service: builtins.str
    def __init__(
        self,
        *,
        methods: collections.abc.Iterable[builtins.str] | None = ...,
        service: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["methods", b"methods", "service", b"service"]) -> None: ...

global___ApikeysKeyXRestrictionsXApiTargets = ApikeysKeyXRestrictionsXApiTargets

@typing_extensions.final
class ApikeysKeyXRestrictionsXBrowserKeyRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_REFERRERS_FIELD_NUMBER: builtins.int
    @property
    def allowed_referrers(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_referrers: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_referrers", b"allowed_referrers"]) -> None: ...

global___ApikeysKeyXRestrictionsXBrowserKeyRestrictions = ApikeysKeyXRestrictionsXBrowserKeyRestrictions

@typing_extensions.final
class ApikeysKeyXRestrictionsXIosKeyRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_BUNDLE_IDS_FIELD_NUMBER: builtins.int
    @property
    def allowed_bundle_ids(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_bundle_ids: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_bundle_ids", b"allowed_bundle_ids"]) -> None: ...

global___ApikeysKeyXRestrictionsXIosKeyRestrictions = ApikeysKeyXRestrictionsXIosKeyRestrictions

@typing_extensions.final
class ApikeysKeyXRestrictionsXServerKeyRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ALLOWED_IPS_FIELD_NUMBER: builtins.int
    @property
    def allowed_ips(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    def __init__(
        self,
        *,
        allowed_ips: collections.abc.Iterable[builtins.str] | None = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["allowed_ips", b"allowed_ips"]) -> None: ...

global___ApikeysKeyXRestrictionsXServerKeyRestrictions = ApikeysKeyXRestrictionsXServerKeyRestrictions

@typing_extensions.final
class ApikeysKeyXRestrictions(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ANDROID_KEY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    API_TARGETS_FIELD_NUMBER: builtins.int
    BROWSER_KEY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    IOS_KEY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    SERVER_KEY_RESTRICTIONS_FIELD_NUMBER: builtins.int
    @property
    def android_key_restrictions(self) -> global___ApikeysKeyXRestrictionsXAndroidKeyRestrictions: ...
    @property
    def api_targets(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___ApikeysKeyXRestrictionsXApiTargets]: ...
    @property
    def browser_key_restrictions(self) -> global___ApikeysKeyXRestrictionsXBrowserKeyRestrictions: ...
    @property
    def ios_key_restrictions(self) -> global___ApikeysKeyXRestrictionsXIosKeyRestrictions: ...
    @property
    def server_key_restrictions(self) -> global___ApikeysKeyXRestrictionsXServerKeyRestrictions: ...
    def __init__(
        self,
        *,
        android_key_restrictions: global___ApikeysKeyXRestrictionsXAndroidKeyRestrictions | None = ...,
        api_targets: collections.abc.Iterable[global___ApikeysKeyXRestrictionsXApiTargets] | None = ...,
        browser_key_restrictions: global___ApikeysKeyXRestrictionsXBrowserKeyRestrictions | None = ...,
        ios_key_restrictions: global___ApikeysKeyXRestrictionsXIosKeyRestrictions | None = ...,
        server_key_restrictions: global___ApikeysKeyXRestrictionsXServerKeyRestrictions | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["android_key_restrictions", b"android_key_restrictions", "browser_key_restrictions", b"browser_key_restrictions", "ios_key_restrictions", b"ios_key_restrictions", "server_key_restrictions", b"server_key_restrictions"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["android_key_restrictions", b"android_key_restrictions", "api_targets", b"api_targets", "browser_key_restrictions", b"browser_key_restrictions", "ios_key_restrictions", b"ios_key_restrictions", "server_key_restrictions", b"server_key_restrictions"]) -> None: ...

global___ApikeysKeyXRestrictions = ApikeysKeyXRestrictions

@typing_extensions.final
class ApikeysKeyXTimeouts(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CREATE_FIELD_NUMBER: builtins.int
    DELETE_FIELD_NUMBER: builtins.int
    UPDATE_FIELD_NUMBER: builtins.int
    create: builtins.str
    delete: builtins.str
    update: builtins.str
    def __init__(
        self,
        *,
        create: builtins.str = ...,
        delete: builtins.str = ...,
        update: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["create", b"create", "delete", b"delete", "update", b"update"]) -> None: ...

global___ApikeysKeyXTimeouts = ApikeysKeyXTimeouts

@typing_extensions.final
class ApikeysKey(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    DISPLAY_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    KEY_STRING_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    PROJECT_FIELD_NUMBER: builtins.int
    UID_FIELD_NUMBER: builtins.int
    RESTRICTIONS_FIELD_NUMBER: builtins.int
    TIMEOUTS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    display_name: builtins.str
    id: builtins.str
    key_string: builtins.str
    name: builtins.str
    project: builtins.str
    uid: builtins.str
    @property
    def restrictions(self) -> global___ApikeysKeyXRestrictions: ...
    @property
    def timeouts(self) -> global___ApikeysKeyXTimeouts: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        display_name: builtins.str = ...,
        id: builtins.str = ...,
        key_string: builtins.str = ...,
        name: builtins.str = ...,
        project: builtins.str = ...,
        uid: builtins.str = ...,
        restrictions: global___ApikeysKeyXRestrictions | None = ...,
        timeouts: global___ApikeysKeyXTimeouts | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "restrictions", b"restrictions", "timeouts", b"timeouts"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["display_name", b"display_name", "id", b"id", "key_string", b"key_string", "name", b"name", "project", b"project", "resource_info", b"resource_info", "restrictions", b"restrictions", "timeouts", b"timeouts", "uid", b"uid"]) -> None: ...

global___ApikeysKey = ApikeysKey



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class Microsoft_Network_routeTables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ROUTE_TABLES_FIELD_NUMBER: builtins.int
    ROUTE_TABLES_ROUTES_FIELD_NUMBER: builtins.int
    @property
    def route_tables(self) -> global___RouteTables: ...
    @property
    def route_tables_routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___RouteTablesRoutes]: ...
    def __init__(
        self,
        *,
        route_tables: global___RouteTables | None = ...,
        route_tables_routes: collections.abc.Iterable[global___RouteTablesRoutes] | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["route_tables", b"route_tables"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["route_tables", b"route_tables", "route_tables_routes", b"route_tables_routes"]) -> None: ...

global___Microsoft_Network_routeTables = Microsoft_Network_routeTables

@typing_extensions.final
class RouteTablesRoutes(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    NEXT_HOP_TYPE_FIELD_NUMBER: builtins.int
    NEXT_HOP_IP_ADDRESS_FIELD_NUMBER: builtins.int
    HAS_BGP_OVERRIDE_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    address_prefix: builtins.str
    next_hop_type: builtins.str
    next_hop_ip_address: builtins.str
    has_bgp_override: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        address_prefix: builtins.str = ...,
        next_hop_type: builtins.str = ...,
        next_hop_ip_address: builtins.str = ...,
        has_bgp_override: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_prefix", b"address_prefix", "has_bgp_override", b"has_bgp_override", "name", b"name", "next_hop_ip_address", b"next_hop_ip_address", "next_hop_type", b"next_hop_type", "resource_info", b"resource_info"]) -> None: ...

global___RouteTablesRoutes = RouteTablesRoutes

@typing_extensions.final
class RouteTables(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    @typing_extensions.final
    class TagsEntry(google.protobuf.message.Message):
        DESCRIPTOR: google.protobuf.descriptor.Descriptor

        KEY_FIELD_NUMBER: builtins.int
        VALUE_FIELD_NUMBER: builtins.int
        key: builtins.str
        value: builtins.str
        def __init__(
            self,
            *,
            key: builtins.str = ...,
            value: builtins.str = ...,
        ) -> None: ...
        def ClearField(self, field_name: typing_extensions.Literal["key", b"key", "value", b"value"]) -> None: ...

    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    LOCATION_FIELD_NUMBER: builtins.int
    TAGS_FIELD_NUMBER: builtins.int
    ROUTES_FIELD_NUMBER: builtins.int
    DISABLE_BGP_ROUTE_PROPAGATION_FIELD_NUMBER: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    name: builtins.str
    location: builtins.str
    @property
    def tags(self) -> google.protobuf.internal.containers.ScalarMap[builtins.str, builtins.str]: ...
    @property
    def routes(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Route]: ...
    disable_bgp_route_propagation: builtins.bool
    def __init__(
        self,
        *,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
        name: builtins.str = ...,
        location: builtins.str = ...,
        tags: collections.abc.Mapping[builtins.str, builtins.str] | None = ...,
        routes: collections.abc.Iterable[global___Route] | None = ...,
        disable_bgp_route_propagation: builtins.bool = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["disable_bgp_route_propagation", b"disable_bgp_route_propagation", "location", b"location", "name", b"name", "resource_info", b"resource_info", "routes", b"routes", "tags", b"tags"]) -> None: ...

global___RouteTables = RouteTables

@typing_extensions.final
class Route(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ADDRESS_PREFIX_FIELD_NUMBER: builtins.int
    NEXT_HOP_TYPE_FIELD_NUMBER: builtins.int
    NEXT_HOP_IP_ADDRESS_FIELD_NUMBER: builtins.int
    HAS_BGP_OVERRIDE_FIELD_NUMBER: builtins.int
    NAME_FIELD_NUMBER: builtins.int
    address_prefix: builtins.str
    next_hop_type: builtins.str
    next_hop_ip_address: builtins.str
    has_bgp_override: builtins.bool
    name: builtins.str
    def __init__(
        self,
        *,
        address_prefix: builtins.str = ...,
        next_hop_type: builtins.str = ...,
        next_hop_ip_address: builtins.str = ...,
        has_bgp_override: builtins.bool = ...,
        name: builtins.str = ...,
    ) -> None: ...
    def ClearField(self, field_name: typing_extensions.Literal["address_prefix", b"address_prefix", "has_bgp_override", b"has_bgp_override", "name", b"name", "next_hop_ip_address", b"next_hop_ip_address", "next_hop_type", b"next_hop_type"]) -> None: ...

global___Route = Route



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aws/aws_datapipeline.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from oak9.tython.models.shared import shared_pb2 as shared_dot_shared__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1a\x61ws/aws_datapipeline.proto\x12\x1coak9.tython.aws.datapipeline\x1a\x13shared/shared.proto\"x\n\x1aPipelineParameterAttribute\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x14\n\x0cstring_value\x18\x03 \x01(\t\"\xac\x01\n\x17PipelineParameterObject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12L\n\nattributes\x18\x02 \x03(\x0b\x32\x38.oak9.tython.aws.datapipeline.PipelineParameterAttribute\x12\n\n\x02id\x18\x03 \x01(\t\"s\n\x16PipelineParameterValue\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\n\n\x02id\x18\x02 \x01(\t\x12\x14\n\x0cstring_value\x18\x03 \x01(\t\"~\n\rPipelineField\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\x11\n\tref_value\x18\x03 \x01(\t\x12\x14\n\x0cstring_value\x18\x04 \x01(\t\"\xa8\x01\n\x16PipelinePipelineObject\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12;\n\x06\x66ields\x18\x02 \x03(\x0b\x32+.oak9.tython.aws.datapipeline.PipelineField\x12\n\n\x02id\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\"j\n\x13PipelinePipelineTag\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x0b\n\x03key\x18\x02 \x01(\t\x12\r\n\x05value\x18\x03 \x01(\t\"\xb4\x03\n\x08Pipeline\x12\x37\n\rresource_info\x18\x01 \x01(\x0b\x32 .oak9.tython.shared.ResourceInfo\x12\x10\n\x08\x61\x63tivate\x18\x02 \x01(\x08\x12\x13\n\x0b\x64\x65scription\x18\x03 \x01(\t\x12\x0c\n\x04name\x18\x04 \x01(\t\x12P\n\x11parameter_objects\x18\x05 \x03(\x0b\x32\x35.oak9.tython.aws.datapipeline.PipelineParameterObject\x12N\n\x10parameter_values\x18\x06 \x03(\x0b\x32\x34.oak9.tython.aws.datapipeline.PipelineParameterValue\x12N\n\x10pipeline_objects\x18\x07 \x03(\x0b\x32\x34.oak9.tython.aws.datapipeline.PipelinePipelineObject\x12H\n\rpipeline_tags\x18\x08 \x03(\x0b\x32\x31.oak9.tython.aws.datapipeline.PipelinePipelineTag\"H\n\x0c\x44\x61taPipeline\x12\x38\n\x08pipeline\x18\x01 \x03(\x0b\x32&.oak9.tython.aws.datapipeline.Pipelineb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aws.aws_datapipeline_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _PIPELINEPARAMETERATTRIBUTE._serialized_start=81
  _PIPELINEPARAMETERATTRIBUTE._serialized_end=201
  _PIPELINEPARAMETEROBJECT._serialized_start=204
  _PIPELINEPARAMETEROBJECT._serialized_end=376
  _PIPELINEPARAMETERVALUE._serialized_start=378
  _PIPELINEPARAMETERVALUE._serialized_end=493
  _PIPELINEFIELD._serialized_start=495
  _PIPELINEFIELD._serialized_end=621
  _PIPELINEPIPELINEOBJECT._serialized_start=624
  _PIPELINEPIPELINEOBJECT._serialized_end=792
  _PIPELINEPIPELINETAG._serialized_start=794
  _PIPELINEPIPELINETAG._serialized_end=900
  _PIPELINE._serialized_start=903
  _PIPELINE._serialized_end=1339
  _DATAPIPELINE._serialized_start=1341
  _DATAPIPELINE._serialized_end=1413
# @@protoc_insertion_point(module_scope)



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import collections.abc
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import kubernetes.kubernetes_io.k8s.api.core.v1_pb2
import kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2
import shared.shared_pb2
import sys

if sys.version_info >= (3, 8):
    import typing as typing_extensions
else:
    import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor

@typing_extensions.final
class CronJob(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___CronJobSpec: ...
    @property
    def status(self) -> global___CronJobStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___CronJobSpec | None = ...,
        status: global___CronJobStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___CronJob = CronJob

@typing_extensions.final
class CronJobList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___CronJob]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___CronJob] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___CronJobList = CronJobList

@typing_extensions.final
class CronJobSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONCURRENCY_POLICY_FIELD_NUMBER: builtins.int
    FAILED_JOBS_HISTORY_LIMIT_FIELD_NUMBER: builtins.int
    JOB_TEMPLATE_FIELD_NUMBER: builtins.int
    SCHEDULE_FIELD_NUMBER: builtins.int
    STARTING_DEADLINE_SECONDS_FIELD_NUMBER: builtins.int
    SUCCESSFUL_JOBS_HISTORY_LIMIT_FIELD_NUMBER: builtins.int
    SUSPEND_FIELD_NUMBER: builtins.int
    TIME_ZONE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    concurrency_policy: builtins.str
    failed_jobs_history_limit: builtins.int
    @property
    def job_template(self) -> global___JobTemplateSpec: ...
    schedule: builtins.str
    starting_deadline_seconds: builtins.int
    successful_jobs_history_limit: builtins.int
    suspend: builtins.bool
    time_zone: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        concurrency_policy: builtins.str = ...,
        failed_jobs_history_limit: builtins.int = ...,
        job_template: global___JobTemplateSpec | None = ...,
        schedule: builtins.str = ...,
        starting_deadline_seconds: builtins.int = ...,
        successful_jobs_history_limit: builtins.int = ...,
        suspend: builtins.bool = ...,
        time_zone: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["job_template", b"job_template", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["concurrency_policy", b"concurrency_policy", "failed_jobs_history_limit", b"failed_jobs_history_limit", "job_template", b"job_template", "resource_info", b"resource_info", "schedule", b"schedule", "starting_deadline_seconds", b"starting_deadline_seconds", "successful_jobs_history_limit", b"successful_jobs_history_limit", "suspend", b"suspend", "time_zone", b"time_zone"]) -> None: ...

global___CronJobSpec = CronJobSpec

@typing_extensions.final
class CronJobStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_FIELD_NUMBER: builtins.int
    LAST_SCHEDULE_TIME_FIELD_NUMBER: builtins.int
    LAST_SUCCESSFUL_TIME_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def active(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference]: ...
    @property
    def last_schedule_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def last_successful_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        active: collections.abc.Iterable[kubernetes.kubernetes_io.k8s.api.core.v1_pb2.ObjectReference] | None = ...,
        last_schedule_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        last_successful_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_schedule_time", b"last_schedule_time", "last_successful_time", b"last_successful_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "last_schedule_time", b"last_schedule_time", "last_successful_time", b"last_successful_time", "resource_info", b"resource_info"]) -> None: ...

global___CronJobStatus = CronJobStatus

@typing_extensions.final
class Job(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___JobSpec: ...
    @property
    def status(self) -> global___JobStatus: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___JobSpec | None = ...,
        status: global___JobStatus | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec", "status", b"status"]) -> None: ...

global___Job = Job

@typing_extensions.final
class JobCondition(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    LAST_PROBE_TIME_FIELD_NUMBER: builtins.int
    LAST_TRANSITION_TIME_FIELD_NUMBER: builtins.int
    MESSAGE_FIELD_NUMBER: builtins.int
    REASON_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def last_probe_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def last_transition_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    message: builtins.str
    reason: builtins.str
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        last_probe_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        last_transition_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        message: builtins.str = ...,
        reason: builtins.str = ...,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["last_probe_time", b"last_probe_time", "last_transition_time", b"last_transition_time", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["last_probe_time", b"last_probe_time", "last_transition_time", b"last_transition_time", "message", b"message", "reason", b"reason", "resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___JobCondition = JobCondition

@typing_extensions.final
class JobList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    API_VERSION_FIELD_NUMBER: builtins.int
    ITEMS_FIELD_NUMBER: builtins.int
    KIND_FIELD_NUMBER: builtins.int
    METADATA_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    api_version: builtins.str
    @property
    def items(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___Job]: ...
    kind: builtins.str
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        api_version: builtins.str = ...,
        items: collections.abc.Iterable[global___Job] | None = ...,
        kind: builtins.str = ...,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ListMeta | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["api_version", b"api_version", "items", b"items", "kind", b"kind", "metadata", b"metadata", "resource_info", b"resource_info"]) -> None: ...

global___JobList = JobList

@typing_extensions.final
class JobSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_DEADLINE_SECONDS_FIELD_NUMBER: builtins.int
    BACKOFF_LIMIT_FIELD_NUMBER: builtins.int
    COMPLETION_MODE_FIELD_NUMBER: builtins.int
    COMPLETIONS_FIELD_NUMBER: builtins.int
    MANUAL_SELECTOR_FIELD_NUMBER: builtins.int
    PARALLELISM_FIELD_NUMBER: builtins.int
    POD_FAILURE_POLICY_FIELD_NUMBER: builtins.int
    SELECTOR_FIELD_NUMBER: builtins.int
    SUSPEND_FIELD_NUMBER: builtins.int
    TEMPLATE_FIELD_NUMBER: builtins.int
    TTL_SECONDS_AFTER_FINISHED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    active_deadline_seconds: builtins.int
    backoff_limit: builtins.int
    completion_mode: builtins.str
    completions: builtins.int
    manual_selector: builtins.bool
    parallelism: builtins.int
    @property
    def pod_failure_policy(self) -> global___PodFailurePolicy: ...
    @property
    def selector(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector: ...
    suspend: builtins.bool
    @property
    def template(self) -> kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec: ...
    ttl_seconds_after_finished: builtins.int
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        active_deadline_seconds: builtins.int = ...,
        backoff_limit: builtins.int = ...,
        completion_mode: builtins.str = ...,
        completions: builtins.int = ...,
        manual_selector: builtins.bool = ...,
        parallelism: builtins.int = ...,
        pod_failure_policy: global___PodFailurePolicy | None = ...,
        selector: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.LabelSelector | None = ...,
        suspend: builtins.bool = ...,
        template: kubernetes.kubernetes_io.k8s.api.core.v1_pb2.PodTemplateSpec | None = ...,
        ttl_seconds_after_finished: builtins.int = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["pod_failure_policy", b"pod_failure_policy", "resource_info", b"resource_info", "selector", b"selector", "template", b"template"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active_deadline_seconds", b"active_deadline_seconds", "backoff_limit", b"backoff_limit", "completion_mode", b"completion_mode", "completions", b"completions", "manual_selector", b"manual_selector", "parallelism", b"parallelism", "pod_failure_policy", b"pod_failure_policy", "resource_info", b"resource_info", "selector", b"selector", "suspend", b"suspend", "template", b"template", "ttl_seconds_after_finished", b"ttl_seconds_after_finished"]) -> None: ...

global___JobSpec = JobSpec

@typing_extensions.final
class JobStatus(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTIVE_FIELD_NUMBER: builtins.int
    COMPLETED_INDEXES_FIELD_NUMBER: builtins.int
    COMPLETION_TIME_FIELD_NUMBER: builtins.int
    CONDITIONS_FIELD_NUMBER: builtins.int
    FAILED_FIELD_NUMBER: builtins.int
    READY_FIELD_NUMBER: builtins.int
    START_TIME_FIELD_NUMBER: builtins.int
    SUCCEEDED_FIELD_NUMBER: builtins.int
    UNCOUNTED_TERMINATED_PODS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    active: builtins.int
    completed_indexes: builtins.str
    @property
    def completion_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    @property
    def conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___JobCondition]: ...
    failed: builtins.int
    ready: builtins.int
    @property
    def start_time(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time: ...
    succeeded: builtins.int
    @property
    def uncounted_terminated_pods(self) -> global___UncountedTerminatedPods: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        active: builtins.int = ...,
        completed_indexes: builtins.str = ...,
        completion_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        conditions: collections.abc.Iterable[global___JobCondition] | None = ...,
        failed: builtins.int = ...,
        ready: builtins.int = ...,
        start_time: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.Time | None = ...,
        succeeded: builtins.int = ...,
        uncounted_terminated_pods: global___UncountedTerminatedPods | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["completion_time", b"completion_time", "resource_info", b"resource_info", "start_time", b"start_time", "uncounted_terminated_pods", b"uncounted_terminated_pods"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["active", b"active", "completed_indexes", b"completed_indexes", "completion_time", b"completion_time", "conditions", b"conditions", "failed", b"failed", "ready", b"ready", "resource_info", b"resource_info", "start_time", b"start_time", "succeeded", b"succeeded", "uncounted_terminated_pods", b"uncounted_terminated_pods"]) -> None: ...

global___JobStatus = JobStatus

@typing_extensions.final
class JobTemplateSpec(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    METADATA_FIELD_NUMBER: builtins.int
    SPEC_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def metadata(self) -> kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta: ...
    @property
    def spec(self) -> global___JobSpec: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        metadata: kubernetes.kubernetes_io.k8s.apimachinery.pkg.apis.meta.v1_pb2.ObjectMeta | None = ...,
        spec: global___JobSpec | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["metadata", b"metadata", "resource_info", b"resource_info", "spec", b"spec"]) -> None: ...

global___JobTemplateSpec = JobTemplateSpec

@typing_extensions.final
class PodFailurePolicy(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    RULES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def rules(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodFailurePolicyRule]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        rules: collections.abc.Iterable[global___PodFailurePolicyRule] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "rules", b"rules"]) -> None: ...

global___PodFailurePolicy = PodFailurePolicy

@typing_extensions.final
class PodFailurePolicyOnExitCodesRequirement(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    CONTAINER_NAME_FIELD_NUMBER: builtins.int
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUES_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    container_name: builtins.str
    operator: builtins.str
    @property
    def values(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.int]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        container_name: builtins.str = ...,
        operator: builtins.str = ...,
        values: collections.abc.Iterable[builtins.int] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["container_name", b"container_name", "operator", b"operator", "resource_info", b"resource_info", "values", b"values"]) -> None: ...

global___PodFailurePolicyOnExitCodesRequirement = PodFailurePolicyOnExitCodesRequirement

@typing_extensions.final
class PodFailurePolicyOnPodConditionsPattern(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    STATUS_FIELD_NUMBER: builtins.int
    TYPE_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    status: builtins.str
    type: builtins.str
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        status: builtins.str = ...,
        type: builtins.str = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info", "status", b"status", "type", b"type"]) -> None: ...

global___PodFailurePolicyOnPodConditionsPattern = PodFailurePolicyOnPodConditionsPattern

@typing_extensions.final
class PodFailurePolicyRule(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    ACTION_FIELD_NUMBER: builtins.int
    ON_EXIT_CODES_FIELD_NUMBER: builtins.int
    ON_POD_CONDITIONS_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    action: builtins.str
    @property
    def on_exit_codes(self) -> global___PodFailurePolicyOnExitCodesRequirement: ...
    @property
    def on_pod_conditions(self) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[global___PodFailurePolicyOnPodConditionsPattern]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        action: builtins.str = ...,
        on_exit_codes: global___PodFailurePolicyOnExitCodesRequirement | None = ...,
        on_pod_conditions: collections.abc.Iterable[global___PodFailurePolicyOnPodConditionsPattern] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["on_exit_codes", b"on_exit_codes", "resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["action", b"action", "on_exit_codes", b"on_exit_codes", "on_pod_conditions", b"on_pod_conditions", "resource_info", b"resource_info"]) -> None: ...

global___PodFailurePolicyRule = PodFailurePolicyRule

@typing_extensions.final
class UncountedTerminatedPods(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor

    FAILED_FIELD_NUMBER: builtins.int
    SUCCEEDED_FIELD_NUMBER: builtins.int
    RESOURCE_INFO_FIELD_NUMBER: builtins.int
    @property
    def failed(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def succeeded(self) -> google.protobuf.internal.containers.RepeatedScalarFieldContainer[builtins.str]: ...
    @property
    def resource_info(self) -> shared.shared_pb2.ResourceInfo: ...
    def __init__(
        self,
        *,
        failed: collections.abc.Iterable[builtins.str] | None = ...,
        succeeded: collections.abc.Iterable[builtins.str] | None = ...,
        resource_info: shared.shared_pb2.ResourceInfo | None = ...,
    ) -> None: ...
    def HasField(self, field_name: typing_extensions.Literal["resource_info", b"resource_info"]) -> builtins.bool: ...
    def ClearField(self, field_name: typing_extensions.Literal["failed", b"failed", "resource_info", b"resource_info", "succeeded", b"succeeded"]) -> None: ...

global___UncountedTerminatedPods = UncountedTerminatedPods
